# License

## Commercial License

**Quantum Entangled Knowledge Graphs (QE-KGR)**

Copyright (c) 2024 QE-KGR Project Contributors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LICommercialED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

---

## Third-Party Licenses

QE-KGR depends on several open-source libraries. Below are their respective licenses:

### NumPy
- **License**: BSD 3-Clause License
- **Copyright**: Copyright (c) 2005-2023, NumPy Developers
- **Website**: https://numpy.org/doc/stable/license.html

### SciPy
- **License**: BSD 3-Clause License  
- **Copyright**: Copyright (c) 2001-2023, SciPy Developers
- **Website**: https://scipy.org/scipylib/license.html

### NetworkX
- **License**: BSD 3-Clause License
- **Copyright**: Copyright (c) 2004-2023, NetworkX Developers
- **Website**: https://networkx.org/documentation/stable/reference/legal.html

### Plotly
- **License**: Commercial License
- **Copyright**: Copyright (c) 2016-2023 Plotly, Inc
- **Website**: https://github.com/plotly/plotly.py/blob/master/LICENSE.txt

### Matplotlib
- **License**: Matplotlib License (based on PSF license)
- **Copyright**: Copyright (c) 2002-2023 Matplotlib Development Team
- **Website**: https://matplotlib.org/stable/users/project/license.html

---

## Academic Use and Citations

### Research and Education

QE-KGR is freely available for academic research and educational purposes. If you use QE-KGR in your research, please cite our work:

```bibtex
@software{qekgr2024,
  title={QE-KGR: Quantum Entangled Knowledge Graphs},
  author={QE-KGR Project Contributors},
  year={2024},
  url={https://github.com/quantum-entangled-knowledge-graphs/qekgr},
  version={1.0.0}
}
```

### Publications

If QE-KGR contributes to your published research, we would appreciate:

1. **Citation** of the QE-KGR library in your references
2. **Acknowledgment** in your paper's acknowledgments section
3. **Notification** to the maintainers about your publication
4. **Sharing** a preprint or final version with the community

---

## Commercial Use

### Commercial Licensing

QE-KGR's Commercial license permits commercial use without additional licensing requirements. However, we encourage commercial users to:

- **Contribute back** improvements to the open-source project
- **Support development** through sponsorship or funding
- **Engage with the community** for collaborative development
- **Share success stories** to help grow the ecosystem

### Enterprise Support

For enterprise users requiring additional support, custom development, or consulting services:

- **Technical Support**: Priority support channels available
- **Custom Development**: Specialized quantum algorithms and features
- **Training and Consulting**: Expert guidance for implementation
- **Service Level Agreements**: Guaranteed response times and support

Contact: enterprise@qekgr.org

---

## Patent Policy

### Patent Grant

Contributors to QE-KGR grant a patent license for any patents they own that are necessarily infringed by the contributed code. This ensures the software remains freely usable.

### Patent Protection

QE-KGR is committed to defensive patent practices:

- **Prior Art**: Contributing to the public knowledge base
- **Open Innovation**: Promoting patent-free quantum computing research
- **Community Protection**: Defending against patent trolling

### Patent Contributions

When contributing code that may be covered by patents:

1. **Disclose** any known patent implications
2. **Grant license** for patents covering contributed code  
3. **Ensure freedom** to operate for all users
4. **Document** any patent-related considerations

---

## Quantum Algorithm Licensing

### Novel Quantum Algorithms

Some quantum algorithms implemented in QE-KGR may be novel contributions to the field:

- **Open Access**: All quantum algorithms are freely available
- **Research Use**: Unrestricted use for research and education
- **Commercial Use**: Permitted under Commercial license terms
- **Attribution**: Credit to original algorithm developers requested

### Quantum Computing Standards

QE-KGR follows established quantum computing standards and conventions:

- **IEEE Standards**: Adherence to quantum computing IEEE standards
- **OpenQASM**: Compatibility with quantum assembly language standards
- **Quantum Software**: Following emerging best practices

---

## Data and Privacy

### User Data

QE-KGR respects user privacy and data rights:

- **No Data Collection**: Library doesn't collect user data
- **Local Processing**: All computation performed locally
- **Privacy by Design**: No telemetry or tracking
- **User Control**: Complete control over data and algorithms

### Example Data

Example datasets and use cases provided with QE-KGR:

- **Synthetic Data**: Most examples use generated data
- **Public Data**: Some examples use publicly available datasets
- **Anonymized Data**: Any real data is properly anonymized
- **Attribution**: Proper attribution for all example data sources

---

## Contributing and Licensing

### Contributor License Agreement

By contributing to QE-KGR, contributors agree to:

1. **License Grant**: Grant Commercial license for contributed code
2. **Patent Grant**: Grant patent license for contributed patents
3. **Original Work**: Confirm contribution is original work
4. **Authority**: Confirm authority to make the contribution

### Code Licensing

All code contributions must be compatible with Commercial license:

- **Commercial Compatible**: BSD, Apache 2.0, and other permissive licenses
- **GPL Incompatible**: Copyleft licenses cannot be included
- **Attribution Required**: Proper attribution for incorporated code
- **License Headers**: Consistent license headers in source files

### Documentation Licensing

Documentation is licensed under Creative Commons:

- **License**: Creative Commons Attribution 4.0 International (CC BY 4.0)
- **Attribution**: Credit to QE-KGR project required
- **Sharing**: Free to share and adapt with attribution
- **Commercial Use**: Permitted with attribution

---

## Liability and Warranties

### Disclaimer of Warranties

QE-KGR is provided "as is" without warranties:

- **No Warranty**: No express or implied warranties
- **Fitness for Purpose**: No guarantee of fitness for particular use
- **Accuracy**: No guarantee of computational accuracy
- **Quantum Correctness**: Best effort to ensure quantum mechanical validity

### Limitation of Liability

Users assume responsibility for:

- **Validation**: Verifying results for their specific use case
- **Testing**: Thorough testing before production use
- **Quantum Effects**: Understanding quantum mechanical implications
- **Performance**: Evaluating performance for their requirements

### Professional Responsibility

For professional or critical applications:

- **Expert Review**: Engage quantum computing experts
- **Independent Validation**: Verify results independently
- **Risk Assessment**: Assess risks of quantum algorithms
- **Professional Standards**: Follow applicable professional standards

---

## Contact Information

### License Questions

For questions about licensing:

- **Email**: legal@qekgr.org
- **Issues**: GitHub repository issues for public questions
- **Documentation**: This document and repository README

### Community

Join the QE-KGR community:

- **GitHub**: https://github.com/quantum-entangled-knowledge-graphs/qekgr
- **Discussions**: GitHub Discussions for community interaction
- **Documentation**: Comprehensive documentation and examples
- **Support**: Community-driven support and assistance

---

*This license file is part of the QE-KGR project documentation and is subject to the same Commercial license terms as the software itself.*
